
# const VTKtypemap = Dict{DataType, Int}(P1=>1, L2=>3, T3=>5,
#     Q4=>9, T4=>10, H8=>12, Q8=>23,
#     L3=>21, T6=>22,
#     T10=>24, H20=>25)
const _VTK_TYPE_MAP = Dict{AbsShapeDesc, Int}(P1=>1, L2=>3, T3=>5, Q4=>9, T4=>10, H8=>12)

"""
    vtkwrite(filename, connectivity)

Write VTK file with the mesh.

- `connectivity` = incidence relation of the type `d -> 0`. It must have a "geom"
  attribute for access to the locations of all the vertices that the
  connectivity incidence relation references.
"""
function vtkwrite(filename, connectivity)
    locs = attribute(connectivity.right, "geom")
    # Fill in a matrix of point coordinates
    points = fill(zero(eltype(locs[1])), length(locs[1]), length(locs))
    for i in 1:length(locs)
        points[:, i] .= locs[i]
    end #
    # Figure out the cell type
    celltype = WriteVTK.VTKCellTypes.VTKCellType(_VTK_TYPE_MAP[shapedesc(connectivity.left)])
    # Prepare an array of the cells
    cells = [MeshCell(celltype, [j for j in retrieve(connectivity, i)]) for i in 1:nrelations(connectivity)]
    vtkfile = vtk_grid(filename, points, cells)
    return vtk_save(vtkfile)
end

"""
    export_MESH(meshfile, mesh)

Import vertices and shapes in the MESH format.

# Output
Data dictionary, with keys
- "`vertices`" (vertices),
- "`shapes`" (array of shape collections).
"""
function export_MESH(meshfile, connectivity)
    meshfilebase, ext = splitext(meshfile)
    # Name of the shape descriptor
    t = shapedesc(connectivity.left).name
    datinfo = [meshfilebase * "-xyz.dat", t, meshfilebase * "-conn.dat"]
    locs = attribute(connectivity.right, "geom")
    open(datinfo[1], "w") do file
        X = [locs[idx] for idx in 1:length(locs)]
        writedlm(file, X, ' ')
    end
    open(datinfo[3], "w") do file
        c = [retrieve(connectivity, idx) for idx in 1:nrelations(connectivity)]
        writedlm(file, c, ' ')
    end
    open(meshfilebase * ".mesh", "w") do file
        writedlm(file, datinfo)
    end

    return true
end
